// Copyright (c) 1997 Andrew Maltsev <am@amsoft.ru>
// All rights reserved
// 
// Configuration reading/analysis (/usr/local/etc/easysql.conf,/etc/easysql.conf)
//
#include <stdlib.h>
#include <string.h>
#include <ctype.h>
#include "es_int.h"

char const *homeDir=NULL;
char const *dbDir="databases";
char const *driversDir="drivers";
bool allowUserConfigs=true;

///////////////////////////////////////////////////////////////////////////////
// Reading configurations file (usually /etc/easysql.conf)
//
bool
getConfig()
{ static bool configured=false;
  if(configured) return true;		// Configuration was already read

// Trying to open one of configuration files. In case of no success
// defaults will be used -- it's not an error
//
  FILE *f=fopen(configFile,"r");
  if(!f)
   { f=fopen(configFile2,"r");
     if(!f)
      { log(D_MISC|D_L1,"No configuration files (%s or %s) found! Using defaults.."
                       ,configFile,configFile2);
      }
   }

// Reading file if it was opened
//
  if(f)
   { char buf[1000];
     while(fgets(buf,1000,f))
      { char *cmd=buf;
        while(isspace(*cmd)) cmd++;
        if(*cmd=='#' || *cmd=='\n' || !*cmd) continue;
        char *val=cmd;
        while(*val && !isspace(*val)) val++;
        if(*val)
         { *val++=0;
           while(*val && isspace(*val)) val++;
         }
        if(!*val)				// We have no one-word commands
         { log(D_MISC|D_L4,"Parameter without arguments (%s), ignored",cmd);
           continue;
         }
        char *s=val;
        while(*s && !isspace(*s)) s++;
        *s=0;
   
      // Analizying
      //
        if(!strcmp(cmd,"home-dir"))
         homeDir=strDup(val);
        else if(!strcmp(cmd,"db-dir"))
         dbDir=strDup(val);
        else if(!strcmp(cmd,"drivers-dir"))
         driversDir=strDup(val);
        else if(!strcmp(cmd,"user-configs"))
         allowUserConfigs=!strcasecmp(val,"true") ||
                          !strcasecmp(val,"yes") ||
                          !strcasecmp(val,"allow") ||
                          !strcasecmp(val,"on") ||
                          !strcasecmp(val,"y");
        else if(!strcmp(cmd,"log-level"))
         easysql_set_log_level(strtoul(val,NULL,0));
        else if(!strcmp(cmd,"log-file"))
         easysql_set_log_file(val);
        else
         log(D_ERROR|D_MISC,"Bad configuration parameter: `%s %s'",cmd,val);
      }
     fclose(f);
   }

// Checking and repairing
//
  if(!homeDir)
   homeDir=defaultHomeDir;
  if(*dbDir!='/')
   dbDir=strDup(qprintf("%s/%s",homeDir,dbDir));
  if(*driversDir!='/')
   driversDir=strDup(qprintf("%s/%s",homeDir,driversDir));

// Printing out to help debug configurations
//
  log(D_MISC|D_L4,"config: home-dir     %s",homeDir);
  log(D_MISC|D_L4,"config: db-dir       %s",dbDir);
  log(D_MISC|D_L4,"config: drivers-dir  %s",driversDir);
  log(D_MISC|D_L4,"config: user-configs %s",allowUserConfigs ? "allow" : "deny");
  log(D_MISC|D_L4,"config: log-level    0x%04X",easysql_get_log_level());
  log(D_MISC|D_L4,"config: log-file     %s",easysql_get_log_file());
  return (configured=true);
}

///////////////////////////////////////////////////////////////////////////////
R("$Id: config.C,v 1.3 1997/09/14 17:20:42 am Exp $");
